@@ -1152,9 +1152,9 @@ window_error (YelpWindow *window, gchar *title, gchar *message, gboolean pop)
 	 GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
 	 GTK_MESSAGE_ERROR,
 	 GTK_BUTTONS_OK,
-	 title);
+	 "%s", title);
     gtk_message_dialog_format_secondary_markup
-	(GTK_MESSAGE_DIALOG (dialog), message);
+	(GTK_MESSAGE_DIALOG (dialog), "%s", message);
 	 gtk_dialog_run (GTK_DIALOG (dialog));
 
     gtk_widget_destroy (dialog);
@@ -1631,7 +1631,10 @@ window_do_load_html (YelpWindow    *window,
     
     window_setup_window (window, type, uri, frag_id, uri, priv->base_uri, need_history);
 
-    file   = g_file_new_for_uri (uri);
+    if (uri[0] == '/')
+	file = g_file_new_for_path (uri);
+    else
+	file = g_file_new_for_uri (uri);
     stream = g_file_read (file, NULL, NULL);
 
     if (stream == NULL) {
@@ -1667,7 +1670,7 @@ window_do_load_html (YelpWindow    *window,
     }
 
     while ((g_input_stream_read_all
-	    ((GInputStream *)stream, buffer, BUFFER_SIZE, &n, NULL, NULL))) {
+	    ((GInputStream *)stream, buffer, BUFFER_SIZE, &n, NULL, NULL)) && n) {
 	gchar *tmp;
 	tmp = g_utf8_strup (buffer, n);
 	if (strstr (tmp, "<FRAMESET")) {
@@ -2487,7 +2490,7 @@ window_about_cb (GtkAction *action, YelpWindow *window)
 			   "copyright", copyright,
 			   "authors", authors,
 			   "translator-credits", translator_credits,
-			   "logo-icon-name", "gnome-help",
+			   "logo-icon-name", "help-browser",
 			   NULL);
 }
 
